@@ -37,6 +37,10 @@ class Container(_base.BaseResource):
     allow_list = True
     allow_head = True
 
+    _query_mapping = resource.QueryParameters(
+        'prefix', 'format'
+    )
+
     # Container body data (when id=None)
     #: The name of the container.
     name = resource.Body("name", alternate_id=True, alias='id')
@@ -94,6 +98,12 @@ class Container(_base.BaseResource):
     #: "If-None-Match: \*" header to query whether the server already
     #: has a copy of the object before any data is sent.
     if_none_match = resource.Header("if-none-match")
+    #: The secret key value for temporary URLs. If not set,
+    #: this header is not returned by this operation.
+    meta_temp_url_key = resource.Header("x-container-meta-temp-url-key")
+    #: A second secret key value for temporary URLs. If not set,
+    #: this header is not returned by this operation.
+    meta_temp_url_key_2 = resource.Header("x-container-meta-temp-url-key-2")
 
     @classmethod
     def new(cls, **kwargs):
@@ -103,9 +113,9 @@ class Container(_base.BaseResource):
         name = kwargs.pop('id', None)
         if name:
             kwargs.setdefault('name', name)
-        return Container(_synchronized=True, **kwargs)
+        return cls(_synchronized=False, **kwargs)
 
-    def create(self, session, prepend_key=True):
+    def create(self, session, prepend_key=True, base_path=None):
         """Create a remote resource based on this instance.
 
         :param session: The session to use for making this request.
@@ -119,9 +129,28 @@ class Container(_base.BaseResource):
                  :data:`Resource.allow_create` is not set to ``True``.
         """
         request = self._prepare_request(
-            requires_id=True, prepend_key=prepend_key)
+            requires_id=True, prepend_key=prepend_key, base_path=base_path)
         response = session.put(
-            request.url, json=request.body, headers=request.headers)
+            request.url, headers=request.headers)
 
         self._translate_response(response, has_body=False)
         return self
+
+    def set_temp_url_key(self, proxy, key, secondary=False):
+        """Set the temporary url key for a container.
+
+        :param proxy: The proxy to use for making this request.
+        :type proxy: :class:`~openstack.proxy.Proxy`
+        :param container:
+          The value can be the name of a container or a
+          :class:`~openstack.object_store.v1.container.Container` instance.
+        :param key:
+          Text of the key to use.
+        :param bool secondary:
+          Whether this should set the second key. (defaults to False)
+        """
+        header = 'Temp-URL-Key'
+        if secondary:
+            header += '-2'
+
+        return self.set_metadata(proxy, {header: key})
