@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
+from openstack.tests.unit import base
 
 from openstack.compute.v2 import server_group
 
@@ -23,17 +23,16 @@ EXAMPLE = {
 }
 
 
-class TestServerGroup(testtools.TestCase):
+class TestServerGroup(base.TestCase):
 
     def test_basic(self):
         sot = server_group.ServerGroup()
         self.assertEqual('server_group', sot.resource_key)
         self.assertEqual('server_groups', sot.resources_key)
         self.assertEqual('/os-server-groups', sot.base_path)
-        self.assertEqual('compute', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertFalse(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertFalse(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
