@@ -11,7 +11,7 @@
 # under the License.
 
 import mock
-import testtools
+from openstack.tests.unit import base
 
 from openstack.network.v2 import flavor
 
@@ -32,16 +32,15 @@ EXAMPLE = {
 }
 
 
-class TestFlavor(testtools.TestCase):
+class TestFlavor(base.TestCase):
     def test_basic(self):
         flavors = flavor.Flavor()
         self.assertEqual('flavor', flavors.resource_key)
         self.assertEqual('flavors', flavors.resources_key)
         self.assertEqual('/flavors', flavors.base_path)
-        self.assertEqual('network', flavors.service.service_type)
         self.assertTrue(flavors.allow_create)
-        self.assertTrue(flavors.allow_get)
-        self.assertTrue(flavors.allow_update)
+        self.assertTrue(flavors.allow_fetch)
+        self.assertTrue(flavors.allow_commit)
         self.assertTrue(flavors.allow_delete)
         self.assertTrue(flavors.allow_list)
 
@@ -76,7 +75,7 @@ class TestFlavor(testtools.TestCase):
                 sess, '1'))
 
         url = 'flavors/IDENTIFIER/service_profiles'
-        sess.post.assert_called_with(url, endpoint_filter=flav.service,
+        sess.post.assert_called_with(url,
                                      json=response.body)
 
     def test_disassociate_flavor_from_service_profile(self):
@@ -91,4 +90,4 @@ class TestFlavor(testtools.TestCase):
                 sess, '1'))
 
         url = 'flavors/IDENTIFIER/service_profiles/1'
-        sess.delete.assert_called_with(url, endpoint_filter=flav.service)
+        sess.delete.assert_called_with(url,)
