@@ -320,6 +320,39 @@ class TestProxyCreate(base.TestCase):
         self.res.create.assert_called_once_with(self.sot, base_path=base_path)
 
 
+class TestProxyBulkCreate(base.TestCase):
+
+    def setUp(self):
+        super(TestProxyBulkCreate, self).setUp()
+
+        class Res(resource.Resource):
+            pass
+
+        self.session = mock.Mock()
+        self.result = mock.sentinel
+        self.data = mock.Mock()
+
+        self.sot = proxy.Proxy(self.session)
+        self.cls = Res
+        self.cls.bulk_create = mock.Mock(return_value=self.result)
+
+    def test_bulk_create_attributes(self):
+        rv = self.sot._bulk_create(self.cls, self.data)
+
+        self.assertEqual(rv, self.result)
+        self.cls.bulk_create.assert_called_once_with(self.sot, self.data,
+                                                     base_path=None)
+
+    def test_bulk_create_attributes_override_base_path(self):
+        base_path = 'dummy'
+
+        rv = self.sot._bulk_create(self.cls, self.data, base_path=base_path)
+
+        self.assertEqual(rv, self.result)
+        self.cls.bulk_create.assert_called_once_with(self.sot, self.data,
+                                                     base_path=base_path)
+
+
 class TestProxyGet(base.TestCase):
 
     def setUp(self):
@@ -467,19 +500,20 @@ class TestExtractName(base.TestCase):
 
     scenarios = [
         ('slash_servers_bare', dict(url='/servers', parts=['servers'])),
-        ('slash_servers_arg', dict(url='/servers/1', parts=['servers'])),
+        ('slash_servers_arg', dict(url='/servers/1', parts=['server'])),
         ('servers_bare', dict(url='servers', parts=['servers'])),
-        ('servers_arg', dict(url='servers/1', parts=['servers'])),
+        ('servers_arg', dict(url='servers/1', parts=['server'])),
         ('networks_bare', dict(url='/v2.0/networks', parts=['networks'])),
-        ('networks_arg', dict(url='/v2.0/networks/1', parts=['networks'])),
+        ('networks_arg', dict(url='/v2.0/networks/1', parts=['network'])),
         ('tokens', dict(url='/v3/tokens', parts=['tokens'])),
         ('discovery', dict(url='/', parts=['discovery'])),
         ('secgroups', dict(
             url='/servers/1/os-security-groups',
-            parts=['servers', 'os-security-groups'])),
+            parts=['server', 'os-security-groups'])),
+        ('bm_chassis', dict(url='/v1/chassis/id', parts=['chassis']))
     ]
 
     def test_extract_name(self):
 
-        results = proxy._extract_name(self.url)
+        results = proxy.Proxy(mock.Mock())._extract_name(self.url)
         self.assertEqual(self.parts, results)
